@@ -1,9 +1,13 @@
 .onLoad <- function(libname, pkgname) {
+  readr_check()
   register_s3_method("dplyr", "db_desc", "AthenaConnection")
   register_s3_method("dbplyr", "db_compute", "AthenaConnection")
   register_s3_method("dplyr", "db_save_query", "AthenaConnection")
   register_s3_method("dbplyr", "db_copy_to", "AthenaConnection")
   register_s3_method("dbplyr", "sql_translate_env", "AthenaConnection")
+  register_s3_method("dbplyr", "sql_escape_string", "AthenaConnection")
+  register_s3_method("dbplyr", "db_explain", "AthenaConnection")
+  register_s3_method("dbplyr", "db_query_fields", "AthenaConnection")
 }
 
 register_s3_method <- function(pkg, generic, class, fun = NULL) {
@@ -28,4 +32,6 @@ register_s3_method <- function(pkg, generic, class, fun = NULL) {
       registerS3method(generic, class, fun, envir = asNamespace(pkg))
     }
   )
-}
\ No newline at end of file
+}
+
+readr_check <- function() if (!requireNamespace("readr", quietly = TRUE)) packageStartupMessage("Info: For extra speed please install `readr`.")
\ No newline at end of file
